# SIMOC JSON to CSV converter by Ezio Melotti, May 2020

'''
This Python script opens the SIMOC simulation output data (JSON) file and 
then extracts a particular agent interaction, in this case water flow. The 
script can be modifed to exract any of the agent interactions.

$ python3 simoc-json2csv.py [name-of-the-data-file].json
'''

import csv
import json
import argparse

from pathlib import Path

def write_csv(file, lines):
    with file.open('w', newline='') as f:
        writer = csv.writer(f)
        writer.writerows(lines)

def read_json(file):
    with json_file.open() as f:
        j = json.load(f)
    print(j['storage_capacities'].values())
    return j

def main(json_file, csv_file):
    j = read_json(json_file)
    lines = []
    for step_num, step_data in j['storage_capacities'].items():
        water_storage_1 = step_data['water_storage']['1']
        line = [data['value'] for label, data in water_storage_1.items()]
        lines.append([step_num, *line])
    print(lines)
    write_csv(csv_file, lines)


if __name__ == '__main__':
    desc = 'Convert simulation data from json to csv.'
    parser = argparse.ArgumentParser(description=desc)
    parser.add_argument('json_file', metavar='JSON_FILE',
                        help='the json file to convert')
    parser.add_argument('csv_file', metavar='CSV_FILE', nargs='?',
                        help='the csv file to create')

    args = parser.parse_args()
    json_file = Path(args.json_file)
    if args.csv_file:
        csv_file = Path(args.csv_file)
    else:
        csv_file = json_file.with_suffix('.csv')
    main(json_file, csv_file)
